@@ -5,6 +5,7 @@ set.seed(4321)
 x <- rnorm(15)^2
 xna <- replace(x, 2, NA)
 w <- runif(15, 0, 2)
+f <- factor(sample(letters[1:3], 15, TRUE))
 
 #---- Tests for transmute_weights ----
 all.equal(transmute_weights(2, 2)(x), rep(1, length(x)))
@@ -12,6 +13,8 @@ all.equal(transmute_weights(0, 0)(xna, w), replace(w, 2, NA))
 all.equal(transmute_weights(1, 1)(c(1, NA)), c(1, NA))
 all.equal(transmute_weights(2, 1)(c(1, NA)), c(1, NA))
 all.equal(transmute_weights(7, -3)(x, transmute_weights(-3, 7)(x, w)), w)
+all.equal(grouped(transmute_weights(1, 2))(x, w, group = f),
+          unsplit(Map(transmute_weights(1, 2), split(x, f), split(w, f)), f))
 
 #---- Tests for contributions ----
 all.equal(arithmetic_contributions(1:4), c(0, 0.25, 0.5, 0.75))
@@ -19,12 +22,15 @@ all.equal(harmonic_contributions(1:4), c(0, 0.24, 0.32, 0.36))
 all.equal(geometric_contributions(c(1, 4)), c(0, 1))
 all.equal(sum(contributions(-3.75)(x, w)), generalized_mean(-3.75)(x, w) - 1)
 all.equal(sum(contributions(3.75)(xna, w), na.rm = TRUE), generalized_mean(3.75)(xna, w, na.rm = TRUE) - 1)
+all.equal(as.numeric(tapply(grouped(geometric_contributions)(x, group = f), f, sum)),
+          as.numeric(tapply(x, f, geometric_mean) - 1))
     
 #---- Tests for factor_weights ----
 all.equal(factor_weights(0)(c(1, NA)), c(1, NA))
 all.equal(factor_weights(0)(x), rep(1, length(x)))
 all.equal(factor_weights(0)(x, w), w)
 all.equal(update_weights(xna, w), xna * w)
+all.equal(grouped(update_weights)(x, w, group = f), x * w)
 
 #---- Tests for scale_weights ----
 all.equal(sum(scale_weights(w)), 1)
